@@ -21,7 +21,7 @@ use Math::BigInt;
 use Math::Random;
 use Fcntl 'SEEK_CUR';
 
-our $VERSION = '1.2';
+our $VERSION = '1.21';
 
 use overload  '+'        =>    '_join',
               '""'       =>    '_str',
@@ -1039,19 +1039,22 @@ sub runs {
     return @allruns
 }
 
-##  Check if the integer value of the bitvector is a prime through the                     
-##  Miller-Rabin probabilistic test of primality.  If not found to be a                    
-##  composite, estimate the probability of the bitvector being a prime using this          
-##  test.                                                                                  
+##  Check if the integer value of the bitvector is a prime through the Miller-Rabin
+##  probabilistic test of primality.  If not found to be a composite, estimate the
+##  probability of the bitvector being a prime using this test.
 sub test_for_primality {
     my $p = int(shift);
+    die "\nThe primality test method test_for_primality() is intended for only " .
+        "small integers --- integers that are relatively small in relation to " .
+        "the largest integer that can fit Perl's 4-byte int representation:$!"
+        if $p > 0x7f_ff_ff_ff;
     my @probes = (2,3,5,7,11,13,17);
     foreach my $a (@probes) {
         return "is a prime" if $a == $p;
     }
     return "is NOT a prime" if any {$p % $_ == 0} @probes;
     my ($k, $q) = (0, $p-1);
-    while (! $q & 1) {
+    while (! ($q & 1)) {
         $q >>= 1;
         $k++;
     }
@@ -1073,9 +1076,10 @@ sub test_for_primality {
     return "is a prime with probability $probability_of_prime";
 }
 
-##  This routine for modular exponentiation of small integers, meaning the integers that can
-##  be accommodated in the native int representation.  For larger integers, a call to this
-##  function should be replaced by a call to modular exponentiation of the BigInt module.
+##  This routine is for modular exponentiation of small integers, meaning the
+##  integers that can be accommodated (before and after exponentiation) in the native
+##  4-byte int representation.  For larger integers, a call to this function should
+##  be replaced by a call to modular exponentiation of the Math::BigInt module.
 sub _powmod_small_ints {
     my $base = shift;
     my $exponent = shift;
@@ -1182,6 +1186,10 @@ bit arrays and for logical and arithmetic operations on such arrays.
 
 =head1 CHANGES
 
+Version 1.21 fixes a bug in the code for the Miller-Rabin primality test function
+C<test_for_primality()>.  This version also places a hard limit on the size of the
+integers that are allowed to be tested for primality.
+
 Version 1.2 fixes an important bug in creating bitvectors from the contents of a disk
 file.  This version also includes corrections for some of the documentation errors
 discovered.
@@ -2110,10 +2118,10 @@ the string 'BitVector' in the subject line.
 Download the archive from CPAN in any directory of your choice.  Unpack the archive
 with a command that on a Linux machine would look like:
 
-    tar zxvf Algorithm-BitVector-1.2.tar.gz
+    tar zxvf Algorithm-BitVector-1.21.tar.gz
 
 This will create an installation directory for you whose name will be
-C<Algorithm-BitVector-1.2>.  Enter this directory and execute the following commands
+C<Algorithm-BitVector-1.21>.  Enter this directory and execute the following commands
 for a standard install of the module if you have root privileges:
 
     perl Makefile.PL
@@ -2142,6 +2150,12 @@ If I used bash, I'd need to declare:
     export PERL5LIB=/some/other/directory/lib64/perl5/:/some/other/directory/share/perl5/
 
 
+=head1 THANKS
+
+The bug in the primality test function, whose fix resulted in Version 1.21, was
+reported by Dana Jacobsen in a bug report filed at C<rt.cpan.org>.  Thanks
+Dana!
+
 =head1 AUTHOR
 
 Avinash Kak, kak@purdue.edu
